PCB Environment: GLWidget Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Slots | Public Member Functions | Static Public Member Functions | Protected Member Functions
GLWidget Class Reference
Inheritance diagram for GLWidget:

## Public Slots
void | animate ()
void | resetZoom ()
void | focusOn (const Object &)
void | showFootprints (bool b)
void | showGridLines (bool b)
void | showGridPoints (bool b)
void | showRatsNest (bool b)
void | showTriangulation (bool b)
void | showGridAStar (bool b)
void | setLimitRatsNest (bool b)

## Public Member Functions
PCBoard * | getPCB () const
void | setPCB (const std::shared_ptr< PCBoard > &)
void | setBottomView (bool b)
void | setLayerAlpha (int z, float a)
void | scheduleSnapshot (const std::string &savePath)
bool | areFootprintsShown () const
bool | areGridLinesShown () const
bool | areGridPointsShown () const
bool | isRatsNestShown () const
bool | isTriangulationShown () const
bool | isRatsNestLimited () const
void | onKeyRelease (QKeyEvent *)

## Static Public Member Functions
static GLWidget * | createInstance (Window *, UIActions *)
static void | deleteInstance ()
static GLWidget * | getInstance ()

## Protected Member Functions
void | initializeGL () override
void | paintEvent (QPaintEvent *) override
void | paintGL () override
void | paintQt (QPainter *, QPaintEvent *)
void | resizeEvent (QResizeEvent *) override
void | mouseMoveEvent (QMouseEvent *) override
void | mousePressEvent (QMouseEvent *) override
void | mouseReleaseEvent (QMouseEvent *) override
void | wheelEvent (QWheelEvent *) override

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/GLWidget.hpp